Crate wurbo

Crate wurbo 

Wurbo-rs

The Experimental Rust crate for the Wurbo framework.

The purpose of this crate is to export a macro that builds the reactivity for you.

This enables you to make your WIT Wasm Component a reactive UI with minimal API surface.

The macro is generate_reactivity! { ... } which takes your render components and generates the reactivity interface for you.

Publish

Publish to crates.io

cargo publish

Modules

error
jinja
Combines data + template to render the HTML
prelude
Prelude to ensure all users have the required deps
utils

Macros

prelude_bindgen
Implements the wurbo_out::Guest trait for the given component.